---
format: gfm
execute:
  echo: false
jupyter: python3
---

```{=html}
<p align="center">
    <a href="https://sprout.seedcase-project.org/">
        <img src="https://raw.githubusercontent.com/seedcase-project/seedcase-sprout/main/_extensions/seedcase-project/seedcase-theme/logos/navbar-logo-seedcase-sprout.svg" alt="Link to Sprout website" height="150"/>
    </a>
</p>
```

## seedcase-sprout: Grow structured, organised, and FAIR data

{{< include /docs/includes/_badges.qmd >}}

Sprout is one component of the [Seedcase
Project](https://seedcase-project.org) framework that aims to take data
created or collected for research studies and "grow" it in a structured
way using modern data engineering best practices. Sprout is designed to
organise, describe, and store data for effective discovery, management,
and analysis.

Check out our [website](https://sprout.seedcase-project.org/) for more
information, such as an
[overview](https://sprout.seedcase-project.org/docs/overview/), how to
use it [guide](https://sprout.seedcase-project.org/docs/guide/), or to
read about the
[design](https://sprout.seedcase-project.org/docs/design/). For a list
of changes, see our
[changelog](https://sprout.seedcase-project.org/docs/releases/) page.

## Installing

Seedcase Sprout can be installed in two ways. The first is to install it
as a user, and the second is to install it as a contributor.

To install Sprout for general use, see our [Installation
Guide](https://sprout.seedcase-project.org/docs/guide/installation).

## Contributing

Check out our [contributing document](CONTRIBUTING.md) for information
on how to contribute to the project, including how to set up your
development environment.

Please note that this project is released with a [Contributor Code of
Conduct](CODE_OF_CONDUCT.md). By participating in this project you agree
to abide by its terms.

## Licensing

This project is licensed under the [MIT License](LICENSE.md).

## Changelog

For a list of changes, see our [changelog](CHANGELOG.md) page.

## Citing

This project is part of the Seedcase Project, which is a collaborative
effort to create a framework for data management and analysis in
research. If you use this project in your work, please cite it as
follows:

```{python}
#| output: asis
!uvx --quiet cffconvert --format apalike
```

Or as a BibTeX entry:

```{python}
!uvx --quiet cffconvert --format bibtex
```
